[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / ProofTypes

# Enumeration: ProofTypes

Types of ownership proofs supported by the system

## Remarks

Supported proof types:
- SelfDeclaration: User self-declares ownership without cryptographic proof
- EIP191: Ethereum personal signature following EIP-191 standard
- SIWE: Sign-In with Ethereum message signature (EIP-4361)
- EIP712: Ethereum typed data signature following EIP-712 standard
- BIP137: Bitcoin message signature following BIP-137
- BIP322: Bitcoin message signature following BIP-322
- TIP191: Tron message signing
- ED25519: Ed25519 signature (used in Solana)
- XRP_ED25519: Ed25519 signature (used in XRP)
- XPUB: Extended public key signature for HD wallets
- MicroTransfer: Proof via small blockchain transaction
- Screenshot: Image proof of ownership/access
- CIP8: Cardano message signing standard (CIP-8)

## See

 - [SignatureProof](../interfaces/SignatureProof.md) For signature-based proofs
 - [DeclarationProof](../interfaces/DeclarationProof.md) For self-declaration proofs
 - [MicroTransferProof](../interfaces/MicroTransferProof.md) For transaction-based proofs
 - [ScreenshotProof](../interfaces/ScreenshotProof.md) For screenshot proofs

## Enumeration Members

### BIP137

> **BIP137**: `"bip-137"`

#### Defined in

[types.ts:1048](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1048)

***

### BIP137\_XPUB

> **BIP137\_XPUB**: `"xpub"`

#### Defined in

[types.ts:1050](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1050)

***

### BIP322

> **BIP322**: `"bip-322"`

#### Defined in

[types.ts:1049](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1049)

***

### CIP8

> **CIP8**: `"cip-8"`

#### Defined in

[types.ts:1054](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1054)

***

### Connect

> **Connect**: `"connect"`

#### Defined in

[types.ts:1057](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1057)

***

### ED25519

> **ED25519**: `"ed25519"`

#### Defined in

[types.ts:1052](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1052)

***

### EIP1271

> **EIP1271**: `"eip-1271"`

#### Defined in

[types.ts:1047](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1047)

***

### EIP191

> **EIP191**: `"eip-191"`

#### Defined in

[types.ts:1045](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1045)

***

### EIP712

> **EIP712**: `"eip-712"`

#### Defined in

[types.ts:1046](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1046)

***

### MicroTransfer

> **MicroTransfer**: `"microtransfer"`

#### Defined in

[types.ts:1055](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1055)

***

### Screenshot

> **Screenshot**: `"screenshot"`

#### Defined in

[types.ts:1056](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1056)

***

### SelfDeclaration

> **SelfDeclaration**: `"self-declaration"`

#### Defined in

[types.ts:1042](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1042)

***

### SIWE

> **SIWE**: `"siwe"`

#### Defined in

[types.ts:1043](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1043)

***

### SIWX

> **SIWX**: `"siwx"`

#### Defined in

[types.ts:1044](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1044)

***

### TIP191

> **TIP191**: `"tip-191"`

#### Defined in

[types.ts:1051](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1051)

***

### XRP\_ED25519

> **XRP\_ED25519**: `"xrp-ed25519"`

#### Defined in

[types.ts:1053](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1053)
