[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / SignatureProof

# Interface: SignatureProof

Interface for signature-based ownership proofs that use cryptographic message signing

## Remarks

Extends the base OwnershipProface to add signature-specific properties:
- Supports multiple signature standards like EIP-191, EIP-712, BIP-137, SIWE
- Includes the cryptographic proof signature string
- Contains an attestation message that was signed
- Records which wallet provider was used for signing

The signature proves ownership by demonstrating control of the private keys
associated with the claimed address.

## See

 - [ProofTypes](../enumerations/ProofTypes.md) For supported signature types
 - [OwnershipProof](OwnershipProof.md) For base proof properties

## Extends

- [`OwnershipProof`](OwnershipProof.md)

## Properties

### address

> **address**: \`$\{string\}:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`address`](OwnershipProof.md#address)

#### Defined in

[types.ts:1085](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1085)

***

### attestation

> **attestation**: `string`

#### Defined in

[types.ts:1121](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1121)

***

### chainSpecificData?

> `optional` **chainSpecificData**: `object`

#### cardanoCoseKey?

> `optional` **cardanoCoseKey**: `string`

#### Defined in

[types.ts:1124](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1124)

***

### did

> **did**: \`did:$\{string\}:$\{string\}\`

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`did`](OwnershipProof.md#did)

#### Defined in

[types.ts:1084](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1084)

***

### proof

> **proof**: `string`

#### Defined in

[types.ts:1120](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1120)

***

### status

> **status**: [`ProofStatus`](../enumerations/ProofStatus.md)

#### Inherited from

[`OwnershipProof`](OwnershipProof.md).[`status`](OwnershipProof.md#status)

#### Defined in

[types.ts:1083](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1083)

***

### type

> **type**: [`SIWE`](../enumerations/ProofTypes.md#siwe) \| [`SIWX`](../enumerations/ProofTypes.md#siwx) \| [`EIP191`](../enumerations/ProofTypes.md#eip191) \| [`EIP712`](../enumerations/ProofTypes.md#eip712) \| [`EIP1271`](../enumerations/ProofTypes.md#eip1271) \| [`BIP137`](../enumerations/ProofTypes.md#bip137) \| [`BIP322`](../enumerations/ProofTypes.md#bip322) \| [`BIP137_XPUB`](../enumerations/ProofTypes.md#bip137_xpub) \| [`TIP191`](../enumerations/ProofTypes.md#tip191) \| [`ED25519`](../enumerations/ProofTypes.md#ed25519) \| [`XRP_ED25519`](../enumerations/ProofTypes.md#xrp_ed25519) \| [`CIP8`](../enumerations/ProofTypes.md#cip8)

#### Overrides

[`OwnershipProof`](OwnershipProof.md).[`type`](OwnershipProof.md#type)

#### Defined in

[types.ts:1106](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1106)

***

### wallet\_provider

> **wallet\_provider**: `string`

#### Defined in

[types.ts:1122](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1122)

***

### xpub?

> `optional` **xpub**: `string`

#### Defined in

[types.ts:1123](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/80aada173fac6a9b5f05869abafa3c1c6cc56aa9/src/types.ts#L1123)
